@@ -1,13 +1,11 @@
+"""Selection data structures module."""
 import dataclasses
 import typing
 
 
 @dataclasses.dataclass(frozen=True)
 class Selection:
-    """
-    Data structure that defines a selection of targets on which
-    to act within the loaded context.
-    """
+    """Data structure defining a selection of targets on which to act."""
 
     bundle_all: bool = True
     function_needles: typing.List[str] = dataclasses.field(default_factory=lambda: [])
